<TS language="sq" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Kliko me të djathtën për të ndryshuar adresën ose etiketen.</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Krijo një adresë të re</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;E re</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Kopjo adresën e zgjedhur në memorjen e sistemit </translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Kopjo</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>afer</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Fshi adresen e selektuar nga lista</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Vendos adresën ose etiketën për të kërkuar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporto të dhënat e skedës korrente në një skedar</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporto</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Fshi</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Zgjidh adresen ku do te dergoni monedhat</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Zgjidh adresën ku do të merrni monedhat</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>Zgjidh</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Duke derguar adresen</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Duke marr adresen</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Këto janë Bitcoin adresat e juaja për të dërguar pagesa. Gjithmon kontrolloni shumën dhe adresën pranuese para se të dërgoni monedha.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation>Këto janë adresat tuaja të Bitcoin për të marrë pagesa. Përdorni butonin 'Krijo adresë të re marrëse' në skedën e marrjes për të krijuar adresa të reja. Nënshkrimi është i mundur vetëm me adresa të tipit 'trashëgimi'.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Kopjo adresen</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopjo &amp;Etiketë</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Ndrysho</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eksporto listën e adresave</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Skedar i ndarë me pikëpresje(*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportimi dështoj</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Gabim gjatë ruajtjes së listës së adresave në %1. Ju lutem provoni prapë.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog i Fjalëkalimit</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Futni fjalëkalimin</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Fjalëkalimi i ri</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Përsërisni fjalëkalimin e ri</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation>Shfaqe fjalëkalimin</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Kripto portofolin</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Ky veprim ka nevojë per fjalëkalimin e portofolit tuaj që të hapë portofolin.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Hap portofolin.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Ky veprim kërkon frazkalimin e portofolit tuaj që të dekriptoj portofolin.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Dekripto portofolin</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Ndrysho fjalëkalimin</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Konfirmoni enkriptimin e portofolit</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Jeni te sigurt te enkriptoni portofolin tuaj?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Portofoli u enkriptua</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Jepe fjalëkalimin e ri për portofolin. Ju lutemi të përdorni një fjalkalim prej dhjetë ose më shumë shkronjave të rëndomta, ose tetë e më shumë fjalë.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Jepe fjalëkalimin e vjetër dhe fjalkalimin e ri për portofolin.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation>Portofoli që duhet të enkriptohet</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation>Portofoli juaj do të enkriptohet</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation>Portofoli juaj është i enkriptuar.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Enkriptimi i portofolit dështoi</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Enkriptimi i portofolit dështoi për shkak të një gabimi të brëndshëm. portofoli juaj nuk u enkriptua.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Frazkalimet e plotësuara nuk përputhen.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ç'kyçja e portofolit dështoi</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Frazkalimi i futur për dekriptimin e portofolit nuk ishte i saktë.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dekriptimi i portofolit dështoi</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Duke u sinkronizuar me rrjetin...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Përmbledhje</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Trego një përmbledhje te përgjithshme të portofolit</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksionet</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Shfleto historinë e transaksioneve</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Mbyllni aplikacionin</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Shfaq informacion rreth Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsione</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Ndrysho frazkalimin e përdorur per enkriptimin e portofolit</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Dergo</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Merr</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Shfaq / Fsheh</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Skedar</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Konfigurimet</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ndihmë</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Shiriti i mjeteve</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 Pas</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Problem</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacion</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>I azhornuar</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Duke u azhornuar...</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Dërgo transaksionin</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Transaksion në ardhje</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation>Portofoli po &lt;b&gt; enkriptohet&lt;/b&gt; dhe është &lt;b&gt; i ç'kyçur&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation>Portofoli po &lt;b&gt; enkriptohet&lt;/b&gt; dhe është &lt;b&gt; i kyçur&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Zgjedhja e monedhes</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopjo adresën</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>po</translation>
    </message>
    <message>
        <source>no</source>
        <translation>jo</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>Portofol</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Ndrysho Adresën</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiketë</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adresa</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Adresë e re dërgimi</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Ndrysho adresën pritëse</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>ndrysho adresën dërguese</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nuk mund të ç'kyçet portofoli.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Krijimi i çelësit të ri dështoi.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation>emri</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>versioni</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Miresevini</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation>Bitcoin</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Problem</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Formilarë</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsionet</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>Portofol</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Problem</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Formilarë</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 dhe %2</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>i/e panjohur</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation>Informacion</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Hap</translation>
    </message>
    <message>
        <source>never</source>
        <translation>asnjehere</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>i/e panjohur</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketë:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Pastro</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Nuk mund të ç'kyçet portofoli.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Kopjo adresen</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Dërgo Monedha</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Fonde te pamjaftueshme</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Shuma:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Dërgo marrësve të ndryshëm njëkohësisht</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Balanca:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Konfirmo veprimin e dërgimit</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>konfirmo dërgimin e monedhave</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Shuma e paguar duhet të jetë më e madhe se 0.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>Sh&amp;uma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation>Paguaj &amp;drejt:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiketë:</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Ngjit nga memorja e sistemit</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Paguaj drejt:</translation>
    </message>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Ngjit nga memorja e sistemit</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Open until %1</source>
        <translation>Hapur deri më %1</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <translation>%1/I pakonfirmuar</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <translation>%1 konfirmimet</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>i/e panjohur</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>transaksionit</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Sasia</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation>Ky panel tregon një përshkrim të detajuar të transaksionit</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloji</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>Open until %1</source>
        <translation>Hapur deri më %1</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation>I/E konfirmuar(%1 konfirmime)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation>I krijuar por i papranuar</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation>Marrë me</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Dërguar drejt</translation>
    </message>
    <message>
        <source>Payment to yourself</source>
        <translation>Pagesë ndaj vetvetes</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minuar</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation>(p/a)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(pa etiketë)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Received with</source>
        <translation>Marrë me</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation>Dërguar drejt</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Minuar</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopjo adresën</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Skedar i ndarë me pikëpresje(*.csv)</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloji</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiketë</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adresë</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Eksportimi dështoj</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Dërgo Monedha</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksporto</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Eksporto të dhënat e skedës korrente në një skedar</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Problem</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Insufficient funds</source>
        <translation>Fonde te pamjaftueshme</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Rikerkim</translation>
    </message>
    </context>
</TS>